@@ -22,6 +22,9 @@ class MenuItem(models.Model):
         return '%s - %s' % (self.menuitem_name, self.lang)
 
     def save(self, *args, **kwargs):
+        """
+        if MenuItem does not contain position, set it to last_item's_position + 1
+        """
 
         if not self.position:
 
@@ -32,6 +35,9 @@ class MenuItem(models.Model):
         super(MenuItem, self).save(*args, **kwargs)
 
     def get_last_position(self):
+        """
+        returns last_item's_position or 0 (no items)
+        """
 
         other_objects = MenuItem.objects.filter(lang=self.lang).order_by('-position')
 
@@ -46,6 +52,9 @@ class MenuItem(models.Model):
         return last_position
 
     def is_first(self):
+        """
+        returns True if self.position is 1, False otherwise
+        """
 
         if self.position == 1:
 
@@ -54,6 +63,11 @@ class MenuItem(models.Model):
         return False
 
     def is_last(self):
+        """
+        if self.position is last, return True, False otherwise
+
+        @return bool
+        """
 
         last_position = self.get_last_position()
 
@@ -64,6 +78,9 @@ class MenuItem(models.Model):
         return False
 
     def increase_position(self):
+        """
+        moves this item to self.position + 1
+        """
 
         if self.is_last():
 
@@ -74,6 +91,9 @@ class MenuItem(models.Model):
             self.swap_with(self.position + 1)
 
     def decrease_position(self):
+        """
+        moves this item to self.position - 1
+        """
 
         if self.is_first():
 
@@ -84,6 +104,9 @@ class MenuItem(models.Model):
             self.swap_with(self.position - 1)
 
     def swap_with(self, position):
+        """
+        handles item moving, makes sure there are no items with same position
+        """
 
         object_to_swap_with = MenuItem.objects.get(lang=self.lang, position=position)
 
@@ -94,6 +117,11 @@ class MenuItem(models.Model):
         self.save()
 
     def is_current(self, page_url):
+        """
+        checks if this is currently active menuitem
+
+        @return bool
+        """
 
         if page_url == self.url or (self.page.index and self.page.active and page_url is None):
 
